import React, { Component } from "react";
import { HashRouter as Router, Route, Link } from "react-router-dom";

import { MuiThemeProvider, createMuiTheme } from "@material-ui/core/styles";

import BrowseDemo from "components/demo/BrowseDemo";
import ConsumptionDemo from "components/demo/ConsumptionDemo";
import ConsumptionArtworkDemo from "components/demo/ConsumptionArtworkDemo";
import ConsumptionAutoDemo from "components/demo/ConsumptionAutoDemo";
import DetailsDemo from "components/demo/DetailsDemo";
import SearchDemo from "components/demo/SearchDemo";

import indigo from "@material-ui/core/colors/indigo";
import amber from "@material-ui/core/colors/amber";

import "./App.css";

const DemoMain = props => {
  return (
    <React.Fragment>
      <Link to="/browse">Browse Page</Link>
      <br />
      <Link to="/detail">Detail Page</Link>
      <br />
      <Link to="/media">Consumption Page</Link>
      <br /> <Link to="/mediaArtwork">Consumption with Artwork Page</Link>
      <br />
      <Link to="/auto/media">Consumption Auto Page</Link>
      <br />
      <Link to="/search">Search Page</Link>
      <br />
    </React.Fragment>
  );
};

class App extends Component {
  constructor(props) {
    super(props);
    this.state = { ih: window.innerHeight };
  }

  componentDidMount() {
    window.addEventListener("resize", this.onResize);
  }

  onResize = evt => {
    this.setState({ ih: window.innerHeight });
  };

  render() {
    var { ih } = this.state;

    const theme = createMuiTheme({
      palette: {
        type: 'dark',
        primary: amber,
        secondary: indigo
      },
      typography: {
        h2: {
          fontSize: ih > 1000 ? "3.9rem" : ih > 600 ? "2.4rem" : "1.312rem",
          lineHeight: ih > 1000 ? "4.1rem" : ih > 600 ? "2.6rem" : "1.16667rem"
        },
        h5: {
          fontSize: ih > 1000 ? "2.3rem" : ih > 600 ? "1.5rem" : "1rem",
          lineHeight: ih > 1000 ? "2.5rem" : ih > 600 ? "1.8rem" : "1.5em",
          fontWeight: "300"
        },
        caption: {
          fontSize: ih > 1000 ? "1.2rem" : ih > 600 ? "1.0rem" : "0.75rem",
          lineHeight: ih > 1000 ? "1.2rem" : ih > 600 ? "1.1rem" : "1.375em"
        }
      }
    });

    // console.log("theme", theme);

    return (
      <MuiThemeProvider theme={theme}>
        <div className="App">
          <Router basename="/">
            <React.Fragment>
              <Route exact={true} path="/" component={DemoMain} />
              <Route path="/browse" component={BrowseDemo} />
              <Route path="/detail" component={DetailsDemo} />
              <Route path="/media" component={ConsumptionDemo} />
              <Route path="/mediaArtwork" component={ConsumptionArtworkDemo} />
              <Route path="/auto/media" component={ConsumptionAutoDemo} />
              <Route path="/search" component={SearchDemo} />
            </React.Fragment>
          </Router>
        </div>
      </MuiThemeProvider>
    );
  }
}

export default App;
